"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGlobalScrollSpy = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const useScrollSpy_1 = require("./useScrollSpy");
/**
 * @param ScrollSpyParams Optional params
 * @param ScrollSpyParams.offsetPx Distance from Y coordinate of the base (px)
 * @param ScrollSpyParams.throttleMs Interval of update processing (ms)
 * @returns ScrollSpyProvider - This Provider components provides useScrollSpy return value descendants of this Provider
 * @returns activeEntry - DOM element activated based on scroll position (only one)
 * @returns actions - Actions are used to control registered DOM elements
 */
const useGlobalScrollSpy = ({ offsetPx = 0, throttleMs = 100, } = {}) => {
    const [activeEntry, actions] = (0, useScrollSpy_1.useScrollSpy)({ offsetPx, throttleMs });
    const ScrollSpyContext = (0, react_1.createContext)({
        activeEntry,
        actions,
    });
    const ScrollSpyProvider = ({ children }) => {
        return ((0, jsx_runtime_1.jsx)(ScrollSpyContext.Provider, Object.assign({ value: { activeEntry, actions } }, { children: children }), void 0));
    };
    const useScrollSpyContext = (0, react_1.useContext)(ScrollSpyContext);
    return { ScrollSpyProvider, ...useScrollSpyContext };
};
exports.useGlobalScrollSpy = useGlobalScrollSpy;
//# sourceMappingURL=useGlobalScrollSpy.js.map