import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext } from "react";
import { useScrollSpy } from "./useScrollSpy";
/**
 * @param ScrollSpyParams Optional params
 * @param ScrollSpyParams.offsetPx Distance from Y coordinate of the base (px)
 * @param ScrollSpyParams.throttleMs Interval of update processing (ms)
 * @returns ScrollSpyProvider - This Provider components provides useScrollSpy return value descendants of this Provider
 * @returns activeEntry - DOM element activated based on scroll position (only one)
 * @returns actions - Actions are used to control registered DOM elements
 */
export const useGlobalScrollSpy = ({ offsetPx = 0, throttleMs = 100, } = {}) => {
    const [activeEntry, actions] = useScrollSpy({ offsetPx, throttleMs });
    const ScrollSpyContext = createContext({
        activeEntry,
        actions,
    });
    const ScrollSpyProvider = ({ children }) => {
        return (_jsx(ScrollSpyContext.Provider, Object.assign({ value: { activeEntry, actions } }, { children: children }), void 0));
    };
    const useScrollSpyContext = useContext(ScrollSpyContext);
    return { ScrollSpyProvider, ...useScrollSpyContext };
};
//# sourceMappingURL=useGlobalScrollSpy.js.map